import numpy as np
import matplotlib.pyplot as plt
from hazma import phase_space
from hazma.parameters import standard_model_masses as sm_masses

cme = 1500.0
states = ["mu", "kl", "k"]
masses = tuple(sm_masses[s] for s in states)
dists_r = phase_space.Rambo(cme, masses).energy_distributions(n=1<<14, nbins=30)
dists_q = phase_space.ThreeBody(cme, masses).energy_distributions(nbins=30)

plt.figure(dpi=150)
colors = ["steelblue", "firebrick", "goldenrod"]
labels = [r"$\mu^{\pm}$", r"$K_{L}$", r"$K^{\pm}$"]
for i in range(3):
  plt.plot(dists_r[i].bin_centers, dists_r[i].probabilities, ls="--", c=colors[i], label=labels[i] + " (rambo)")
  plt.plot(dists_q[i].bin_centers, dists_q[i].probabilities, ls="-", c=colors[i], label=labels[i] + " (quad)")

plt.xlabel(r"$\epsilon \ [\mathrm{MeV}]$", fontsize=16)
plt.ylabel(r"$P(\epsilon) \ [\mathrm{MeV}^{-1}]$", fontsize=16)
plt.tight_layout()
plt.ylim(1e-3, 7e-3)
# plt.xlim(np.min(energies), np.max(energies))
plt.legend(ncol=3)
plt.show()